@@ -146,18 +146,6 @@ main (int argc,
 
   g_set_prgname (PACKAGE_NAME);
 
-  /* initialise thread support. It can be called just once, so check it already
-   * ON and call if if it's not.
-   * Threads are needed by Async APIs.
-   */
-  if (!g_thread_supported ())
-    {
-      DEBUG ("Initializing GThread");
-      g_thread_init (NULL);
-    }
-  else
-    DEBUG ("GThread already initialized. Brilliant!");
-
   tp_debug_divert_messages (g_getenv ("TPL_LOGFILE"));
 
 #ifdef ENABLE_DEBUG
@@ -187,7 +175,15 @@ main (int argc,
   DEBUG ("- TplCallChannel registered.");
 #endif /* ENABLE_CALL */
 
-  observer = _tpl_observer_new ();
+
+  observer = _tpl_observer_dup (&error);
+
+  if (observer == NULL) {
+    g_critical ("Failed to create observer: %s", error->message);
+    g_error_free (error);
+    goto out;
+  }
+
   DEBUG ("Registering channel factory into TplObserver");
   _tpl_observer_set_channel_factory (observer, _tpl_channel_factory_build);
 
