@@ -4,16 +4,15 @@
 #include "lib/simple-account.h"
 #include "lib/simple-account-manager.h"
 
-#include <telepathy-logger/debug-internal.h>
-#include <telepathy-logger/log-manager-internal.h>
-#include <telepathy-logger/log-store-internal.h>
+#include "telepathy-logger/debug-internal.h"
+#include "telepathy-logger/log-manager-internal.h"
+#include "telepathy-logger/log-store-internal.h"
 
 #include <telepathy-glib/debug-sender.h>
 
-/* it was defined in telepathy-logger/log-store-pidgin.c */
+/* it was defined in telepathy-logger/log-manager.c */
 #undef DEBUG_FLAG
 #define DEBUG_FLAG TPL_DEBUG_TESTSUITE
-#include <telepathy-logger/debug-internal.h>
 
 #define ACCOUNT_PATH_JABBER TP_ACCOUNT_OBJECT_PATH_BASE "gabble/jabber/user_40collabora_2eco_2euk"
 #define MY_ID "user@collabora.co.uk"
@@ -414,6 +413,22 @@ test_get_filtered_events (TestCaseFixture *fixture,
 }
 
 
+static void
+get_entities_37288_cb (GObject *object,
+    GAsyncResult *result,
+    gpointer user_data)
+{
+  TestCaseFixture *fixture = user_data;
+  GError *error = NULL;
+
+  tpl_log_manager_get_entities_finish (TPL_LOG_MANAGER (object), result,
+      NULL, &error);
+
+  g_assert_no_error (error);
+  g_main_loop_quit (fixture->main_loop);
+}
+
+
 static void
 get_entities_cb (GObject *object,
     GAsyncResult *result,
@@ -440,7 +455,7 @@ test_get_entities (TestCaseFixture *fixture,
       get_entities_cb, fixture);
   g_main_loop_run (fixture->main_loop);
 
-  g_assert_cmpint (g_list_length (fixture->ret), ==, 2);
+  g_assert_cmpint (g_list_length (fixture->ret), ==, 5);
 
   /* we do not want duplicates */
   fixture->ret = g_list_sort (fixture->ret, (GCompareFunc) _tpl_entity_compare);
@@ -450,6 +465,13 @@ test_get_entities (TestCaseFixture *fixture,
 
   g_list_foreach (fixture->ret, (GFunc) g_object_unref, NULL);
   g_list_free (fixture->ret);
+
+  /* Check that the GSimpleAsyncResult res_gpointer's GDestroyNotify func
+   * is the appropriate one.
+   * Reproduces: https://bugs.freedesktop.org/show_bug.cgi?id=37288 */
+  tpl_log_manager_get_entities_async (fixture->manager, fixture->account,
+      get_entities_37288_cb, fixture);
+  g_main_loop_run (fixture->main_loop);
 }
 
 
